@@ -218,7 +218,7 @@ class Crp:
         last_month_df = train_df[(train_df.order_date >= total_spent_last_month_sep - pd.DateOffset(days = lastTimeflagParam)) & (train_df.order_date <= total_spent_last_month_sep)]
         
         last_month_spent = last_month_df.groupby('customerid').agg({'totalprice':
-                                                        'sum'}).reset_index().rename(columns = {'totalprice':'LastMonthTotalSPent'})
+                                                        'sum'}).reset_index().rename(columns = {'totalprice':'LatestTotalSPent'})
         
         df_matrix = df_matrix.reset_index()
 
@@ -273,7 +273,7 @@ class Crp:
 
         orders_param.columns = orders_param.columns.str.lower()
 
-        output = pd.merge(df_matrix,orders_param,on='customerid',how ='left')
+        output = pd.merge(df_matrix,orders_param,how='left',on='customerid')
 
         output = output.fillna(999)
         
@@ -309,9 +309,9 @@ class Crp:
             customer_name     ->
             train_window      -> 
             sq_pass           -> 
-        -------------------------------__version__
+        -------------------------------
         Output:
-        :")
+        
         """
         
 
